@@ -34,6 +34,10 @@ DespotifyWrap::DespotifyWrap() {
     qDebug() << "Starting thread...";
     this->player->start(QThread::HighPriority);
 
+    this->lastlist=NULL;
+    this->playlists=NULL;
+    this->pending_list=NULL;
+
 }
 
 DespotifyWrap::~DespotifyWrap() {
@@ -57,15 +61,17 @@ bool DespotifyWrap::Authenticate(char *user, char *pass) {
 
 bool DespotifyWrap::UpdatePlaylists() {
      /* Fetch playlists */
-     qDebug() << "Updating playslists";
-
      playlist *current_playlist = despotify_get_stored_playlists(ds);
-
      this->playlists = current_playlist;
-     qDebug() << "Sending signal PlaylistUpdated()";
-     emit this->PlaylistsUpdated();
-
-     return true;
+     if(this->playlists != NULL) {
+         qDebug() << "Playlists updated()";
+         emit this->PlaylistsUpdated();
+        return true;
+    } else {
+        qDebug() << "No playlists fetched:" << despotify_get_error(ds);
+        emit this->PlaylistsUpdated();
+        return false;
+    }
 }
 
 bool DespotifyWrap::IsInitialized() {
@@ -106,7 +112,7 @@ bool DespotifyWrap::Search(char *searchstring) {
      //this->player->Pause();
 
      search = despotify_search(this->ds, searchstring, MAX_SEARCH_RESULTS);
-     if (!search) {
+     if (search==NULL) {
          qDebug() << " search failed: " << despotify_get_error(this->ds);
          return false;
      } else {
@@ -117,40 +123,45 @@ bool DespotifyWrap::Search(char *searchstring) {
 }
 
 void DespotifyWrap::PlayNext() {
-
-    track *t = this->lastlist->tracks;
-    int offset = 0;
-    for (int i=0; i<=current_offset && t; i++) {
-        t = t->next;
-        offset = i+1;
-    }
-    if(!t) {
-        offset = 0;
-    }
-    this->Play(offset);
-
-}
-
-void DespotifyWrap::PlayPrev() {
-
-    track *t = this->lastlist->tracks;
-    int offset = 0;
-    if(this->current_offset==0) {
-        for (int i=0; t->next; i++) {
+    /* Check for valid and loaded playlist */
+    if(this->lastlist!=NULL){
+        track *t = this->lastlist->tracks;
+        int offset = 0;
+        for (int i=0; i<=current_offset && t; i++) {
             t = t->next;
             offset = i+1;
         }
-    } else {
-        for (int i=0; i<this->current_offset && t; i++) {
-            t = t->next;
-            offset = i;
+        if(!t) {
+            offset = 0;
         }
+        this->Play(offset);
     }
+}
+
+void DespotifyWrap::PlayPrev() {
+    /* Check for valid and loaded playlist */
+    if(this->lastlist!=NULL){
+
+        track *t = this->lastlist->tracks;
+        int offset = 0;
+        if(this->current_offset==0) {
+            for (int i=0; t->next; i++) {
+                t = t->next;
+                offset = i+1;
+            }
+        } else {
+            for (int i=0; i<this->current_offset && t; i++) {
+                t = t->next;
+                offset = i;
+            }
+        }
+
+        if(!t) {
+            offset = 0;
+        }
+        this->Play(offset);
 
-    if(!t) {
-        offset = 0;
     }
-    this->Play(offset);
 }
 
 void DespotifyWrap::Exit() {
