@@ -82,6 +82,7 @@ void MainWindow::on_pbLogin_clicked()
         qApp->processEvents();
 
         this->dw->UpdatePlaylists();
+
     }
 }
 
@@ -97,7 +98,7 @@ void MainWindow::PlaylistsUpdated() {
 
     /* Insert all playlists in combo box */
     playlist* p = this->dw->GetPlaylists();
-    if(p){
+    if(p && p != NULL){
         this->ui->cbPlaylists->addItem(tr("Select playlist"),QString("0"));
         for (; p; p = p->next)
         {
@@ -136,16 +137,15 @@ void MainWindow::PrintTracks() {
             if(t->playable) {
 
                 QTreeWidgetItem *t_item = new QTreeWidgetItem(this->ui->twSongs);
+                t_item->setSizeHint(0,QSize(60,45));
                 t_item->setText(0, QString("%1").arg(count + 1,3,10,QChar(' ')));
                 t_item->setText(1, t_song);
-                t_item->setText(2, t_artist);
-                t_item->setText(3, t_album);
+                t_item->setText(2, t_album);
+                t_item->setText(3, t_artist);
                 t_item->setText(4, t_length);
                 int icon=(int)(t->popularity*10/2);
                 if(icon>0&&icon<6) {
                     t_item->setIcon(5, QPixmap(QString(":/gfx/res/rating_%1.png").arg(icon)));
-                    /*t_item->setText(5, QString().setNum(t_popularity,));
-                    t_item->setForeground(5,t_item->backgroundColor(5));*/
                 }
             }
         }
@@ -164,11 +164,13 @@ void MainWindow::on_twSongs_itemDoubleClicked(QTreeWidgetItem* item, int column)
 
 void MainWindow::on_pushButton_4_clicked()
 {
+    qDebug() << "test2";
     this->dw->PlayPrev();
 }
 
 void MainWindow::on_pushButton_3_clicked()
 {
+    qDebug() << "test";
     this->dw->PlayNext();
 }
 
@@ -225,7 +227,7 @@ void MainWindow::on_cbPlaylists_currentIndexChanged(int index)
     qDebug() << "Show playlist button clicked";
     /* Iterate through all playlists */
     playlist* p = this->dw->GetPlaylists();
-    if(p) {
+    if(p!=NULL) {
         for(; p; p = p->next)
         {
             if(QString((char*)p->playlist_id) == this->ui->cbPlaylists->itemData(this->ui->cbPlaylists->currentIndex())) {
@@ -247,7 +249,13 @@ void MainWindow::on_leSearch_returnPressed()
 
     this->ui->leSearch->setText(QString(""));
 }
-void MainWindow::on_cbPlaylists_currentIndexChanged(QString )
-{
 
+void MainWindow::on_pushButton_2_clicked()
+{
+    this->on_leSearch_returnPressed();
+}
+
+void MainWindow::on_twSongs_itemEntered(QTreeWidgetItem* item, int column)
+{
+    item->setSelected(true);
 }
