@@ -58,7 +58,8 @@ private:
 
 private slots:
     /* Ui related */
-    void on_cbPlaylists_currentIndexChanged(QString );
+    void on_twSongs_itemEntered(QTreeWidgetItem* item, int column);
+    void on_pushButton_2_clicked();
     void on_leSearch_returnPressed();
     void on_pushButton_clicked();
     void on_pushButton_3_clicked();
